@@ -1,7 +1,7 @@
 # ============================================================
 #
 # Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
-#               2011 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011, 2012 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -23,6 +23,14 @@
 #
 # ============================================================
 
+"""
+This module contains different transport implementations for RSB and their
+common base classes and utility functions.
+
+@author: jmoringe
+@author: jwienke
+"""
+
 import copy
 import threading
 
@@ -46,12 +54,15 @@ class Connector(object):
         """
         self.__logger = getLoggerByClass(self.__class__)
 
+        self.__wireType = None
+        self.__scope    = None
+
         if wireType == None:
             raise ValueError("Wire type must be a type object, None given")
 
         self.__logger.debug("Using specified converter map for wire-type %s" % wireType)
         self.__wireType = wireType
-        
+
         # fails if still some arguments are left over
         super(Connector, self).__init__(**kwargs)
 
@@ -65,14 +76,20 @@ class Connector(object):
 
     wireType = property(getWireType)
 
-    def setScope(self, scope):
-        """
-        Sets the scope this connector will receive events from. Called before
-        #activate.
+    def getScope(self):
+        return self.__scope
 
-        @param scope: scope scope of the connector
+    def setScope(self, newValue):
         """
-        pass
+        Sets the scope this connector will receive events from to
+        B{newValue}. Called before #activate.
+
+        @param newValue: scope of the connector
+        @type newValue: rsb.Scope
+        """
+        self.__scope = newValue
+
+    scope = property(getScope, setScope)
 
     def activate(self):
         raise NotImplementedError()
